Summary:        Audio Plugin Standard
Name:           lv2
Version:        1.18.8
Release:        4%{?dist}
License:        ISC
URL:            https://lv2plug.in
Source0:        https://lv2plug.in/spec/lv2-%{version}.tar.xz

BuildRequires:  gcc-c++ meson cmake asciidoc graphviz
Buildrequires:  cairo-devel libsndfile-devel pkgconfig(samplerate)
# For docs
BuildRequires:  python3-pygments python3-markdown python3-lxml python3-rdflib doxygen
Provides:       lv2core = 6.0
Provides:       lv2-ui = 2.4

%description
LV2 is an extensible open standard for audio plugins. LV2 has a simple core interface,
which is accompanied by extensions that add more advanced functionality.

Many types of plugins can be built with LV2, including audio effects, synthesizers,
and control processors for modulation and automation. Extensions support more powerful
features, such as:
1.Platform-native UIs
2.Network-transparent plugin control
3.Portable and archivable persistent state
4.Non-realtime tasks (like file loading) with sample-accurate export
5.Semantic control with meaningful control designations and value units


%package        devel
Summary:        API for the LV2 Audio Plugin Standard
Requires:       %{name} = %{version}-%{release}
Requires:       python3-rdflib python3-markdown
Provides:       lv2core-devel = 6.0-4
Provides:       lv2-ui-devel = 2.4-5

%description    devel
lv2-devel contains the lv2.h header file and headers for all of the
LV2 specification extensions and bundles, also includes documents
for %{name} API.


%package        example-plugins
Summary:        Examples of the LV2 Audio Plugin Standard
Requires:       %{name} = %{version}-%{release}

%description    example-plugins
Example plugins for the LV2 Audio Plugin Standard.


%prep
%autosetup -p1
sed -i '1s|^#!.*|#!%{__python3}|' lv2specgen/lv2specgen.py


%build
%meson -D docs=enabled -D old_headers=true -D tests=disabled
%meson_build


%install
%meson_install
rm -fr %{buildroot}%{_docdir}/%{name}


%files
%license COPYING
%doc NEWS README.md
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/atom.lv2
%{_libdir}/%{name}/buf-size.lv2
%{_libdir}/%{name}/core.lv2
%{_libdir}/%{name}/data-access.lv2
%{_libdir}/%{name}/dynmanifest.lv2
%{_libdir}/%{name}/event.lv2
%{_libdir}/%{name}/instance-access.lv2
%{_libdir}/%{name}/log.lv2
%{_libdir}/%{name}/midi.lv2
%{_libdir}/%{name}/morph.lv2
%{_libdir}/%{name}/options.lv2
%{_libdir}/%{name}/parameters.lv2
%{_libdir}/%{name}/patch.lv2
%{_libdir}/%{name}/port-groups.lv2
%{_libdir}/%{name}/port-props.lv2
%{_libdir}/%{name}/presets.lv2
%{_libdir}/%{name}/resize-port.lv2
%{_libdir}/%{name}/schemas.lv2
%{_libdir}/%{name}/state.lv2
%{_libdir}/%{name}/time.lv2
%{_libdir}/%{name}/ui.lv2
%{_libdir}/%{name}/units.lv2
%{_libdir}/%{name}/uri-map.lv2
%{_libdir}/%{name}/urid.lv2
%{_libdir}/%{name}/worker.lv2


%files devel
%{_bindir}/lv2specgen.py
%{_bindir}/lv2_validate
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_includedir}/lv2.h
%{_datadir}/lv2specgen
%doc %{_vpath_builddir}/doc/*


%files example-plugins
%{_libdir}/%{name}/eg-amp.lv2
%{_libdir}/%{name}/eg-fifths.lv2
%{_libdir}/%{name}/eg-metro.lv2
%{_libdir}/%{name}/eg-midigate.lv2
%{_libdir}/%{name}/eg-params.lv2
%{_libdir}/%{name}/eg-sampler.lv2
%{_libdir}/%{name}/eg-scope.lv2


%changelog
* Mon Nov 13 2023 cunshunxia@tencent.com - 1.18.8-4
- Rebuilt for libsndfile 1.2.0-4

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.18.8-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.18.8-2
- Rebuilt for OpenCloudOS Stream 23.05

* Sun Apr 23 2023 rockerzhu <rockerzhu@tencent.com> - 1.18.8-1
- Initial build. Don't upgrade to 1.18.10 due to https://gitlab.com/lv2/lv2/-/issues/57.
